export type Success<T> = { status: "success"; data: T }
export type Failure<T> = { status: "failure"; data: T }
export type Result<OK, Err> = Success<OK> | Failure<Err>

export interface OAuthTokenResponse {
  access_token: string
  expires_in: number
  refresh_token_expires_in: number
  refresh_token_absolute_expires_in: number
  token_type: "Bearer"
  refresh_token: string
}

export type BookingStatus = "PENDING" | "BOOKED"

/**
 * 18-character unique ID used to identify a transaction
 * The value is "000000000000000000" until the transaction is booked, and might be set a few days later
 */
export type NonUniqueId = "000000000000000000" | `${number}`

export interface SB1Transaction {
  id: string
  nonUniqueId: NonUniqueId
  // The Id of the account
  accountKey: string
  // Unix time
  date: number
  // Amount in NOK
  amount: number
  cleanedDescription: string
  remoteAccountName: string
  bookingStatus: BookingStatus

  [key: string]: string | number | boolean | unknown
}

export interface TransactionResponse {
  transactions: ReadonlyArray<SB1Transaction>
}
